"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetNameEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player name updated.
 */
class PlayerSetNameEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The name that the player had before.
     */
    oldName, 
    /**
     * The new name that the player has.
     */
    newName) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldName = oldName;
        this.newName = newName;
        this.eventName = "player.setname";
        this._alteredName = newName;
    }
    /**
     * The altered name that the player will have set instead, if changed.
     */
    get alteredName() {
        return this._alteredName;
    }
    /**
     * Revert the player's name back to their old name.
     */
    revert() {
        this.setName(this.oldName);
    }
    /**
     * Change the name that the player had set.
     * @param name The name to set.
     */
    setName(name) {
        this._alteredName = name;
    }
}
exports.PlayerSetNameEvent = PlayerSetNameEvent;
PlayerSetNameEvent.eventName = "player.setname";
//# sourceMappingURL=SetName.js.map