"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlayerSetNameplateEvent = void 0;
const events_1 = require("@skeldjs/events");
/**
 * Emitted when a player has their player nameplate updated.
 */
class PlayerSetNameplateEvent extends events_1.BasicEvent {
    constructor(room, player, message, 
    /**
     * The nameplate that the player had before.
     */
    oldNameplateId, 
    /**
     * The new nameplate that the player has.
     */
    newNameplateId) {
        super();
        this.room = room;
        this.player = player;
        this.message = message;
        this.oldNameplateId = oldNameplateId;
        this.newNameplateId = newNameplateId;
        this.eventName = "player.setnameplate";
        this._alteredNameplateId = newNameplateId;
    }
    /**
     * The altered nameplate that the player will have set instead, if changed.
     */
    get alteredNameplateId() {
        return this._alteredNameplateId;
    }
    /**
     * Revert the player's nameplate back to their old nameplate.
     */
    revert() {
        this.setNameplate(this.oldNameplateId);
    }
    /**
     * Change the nameplate that the player had set.
     * @param nameplate The nameplate to set.
     */
    setNameplate(nameplate) {
        this._alteredNameplateId = nameplate;
    }
}
exports.PlayerSetNameplateEvent = PlayerSetNameplateEvent;
PlayerSetNameplateEvent.eventName = "player.setnameplate";
//# sourceMappingURL=SetNameplate.js.map